@@ -25,13 +25,18 @@ def main(argv=sys.argv[1:]):
     dist = pkg_resources.get_distribution('pyladies')
 
     parser = argparse.ArgumentParser(
-        description="Everything you need to start your own PyLadies location",
-        version=dist.version
+        description="Everything you need to start your own PyLadies location"
     )
     parser.add_argument(
         'handbook',
         help='read the handbook',
     )
+    parser.add_argument('--version',
+        action='version', default=argparse.SUPPRESS,
+        version=dist.version,
+        help="show program's version number and exit"
+    )
+
     parsed_args = parser.parse_args(argv)
 
     if parsed_args.handbook:
